RcPool

Struct RcPool 

pub struct RcPool<T: Sized>(/* private fields */);
A single thread, interior mutable memory Pool backed by a reference count. This allows objects to hold references back to the pool to keep it alive without carrying a lifetime.

Implementations

Source

impl<T> RcPool<T>

pub fn new() -> Self

Creates a new RcPool for objects of type T.