pub struct RcPool<T: Sized>(/* private fields */);Expand description
A single thread, interior mutable memory Pool backed by a reference count. This allows objects to hold references back to the pool to keep it alive without carrying a lifetime.
Implementations